@@ -1,7 +1,6 @@
-from PyQt5.QtGui import QIcon, QFont
 from PyQt5.QtCore import QModelIndex, Qt
+from PyQt5.QtGui import QIcon
 
-from urh import constants
 from urh.models.ProtocolTreeModel import ProtocolTreeModel
 
 
@@ -16,14 +15,19 @@ class GeneratorTreeModel(ProtocolTreeModel):
         if not index.isValid():
             return Qt.ItemIsEnabled
 
-        return Qt.ItemIsEnabled | Qt.ItemIsSelectable | Qt.ItemIsDragEnabled | Qt.ItemIsDropEnabled
+        return (
+            Qt.ItemIsEnabled
+            | Qt.ItemIsSelectable
+            | Qt.ItemIsDragEnabled
+            | Qt.ItemIsDropEnabled
+        )
 
     def mimeTypes(self):
-        return [] # Prohibit Drag Drop in Generator
+        return []  # Prohibit Drag Drop in Generator
 
     def data(self, index: QModelIndex, role=None):
         item = self.getItem(index)
-        if role == Qt.DisplayRole:#
+        if role == Qt.DisplayRole:  #
             return item.data()
         elif role == Qt.DecorationRole and item.is_group:
-            return QIcon.fromTheme("folder")
\ No newline at end of file
+            return QIcon.fromTheme("folder")
